const path = require('path');
const Sequelize = require('sequelize');

// Configurar Sequelize para usar SQLite.
// El fichero con la BBDD es quiz.sqlite.
const sequelize = new Sequelize("sqlite:quiz.sqlite", {logging: false});

// Importar modelos.
sequelize.import(path.join(__dirname,'quiz'));
sequelize.import(path.join(__dirname,'user'));
sequelize.import(path.join(__dirname,'tip'));

// Relaciones entre modelos
const {quiz, tip, user} = sequelize.models;

// Relacion 1 a N entre User y Quiz:
user.hasMany(quiz, {foreignKey: 'authorId'});
quiz.belongsTo(user, {as: 'author', foreignKey: 'authorId'});

// Relacion 1 a N entre Tip y Quiz:
quiz.hasMany(tip);
tip.belongsTo(quiz);

// Relacion N a N para los favoritos:
quiz.belongsToMany(user, {as: 'fans', through: 'favourites',
                          foreignKey: 'quizId', otherKey: 'userId'});

user.belongsToMany(quiz, {as: 'favouriteQuizzes', through: 'favourites',
                          foreignKey: 'userId', otherKey: 'quizId'});

// Crear tablas pendientes: 
sequelize.sync()

// Exportar modelos:
module.exports = sequelize;
